<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>Configuração do Tema do Mouse do LXQT</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="46"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>Selecione o tema do cursor que você deseja usar (coloque o cursor em cima para testar).&lt;b&gt;Precisa reiniciar a sessão LXQt após esta alteração&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="23"/>
        <source>&amp;Install New Theme...</source>
        <translation>&amp;Instalar Novo Tema...</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="72"/>
        <source>LXQt session needs restart to view this change.</source>
        <translation>A sessão do LXQt precisa ser reiniciada para visualizar esta alteração.</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="91"/>
        <source>&amp;Remove Theme</source>
        <translation>&amp;Remover Tema</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="111"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="233"/>
        <source>XCurTheme error</source>
        <translation>Erro XCurTheme</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="234"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>Você não pode remover o tema ativo!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation>Formulário</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation>O LXQt não encontrou nenhum tema de cursor. O tema padrão do cursor X11 será usado no lugar. LXQt procurou nos seguintes diretórios:</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation>Exibir...</translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
</context>
</TS>
